pub unsafe extern "C" fn kcapi_cipher_decrypt(
    handle: *mut kcapi_handle,
    in_: *const u8,
    inlen: size_t,
    iv: *const u8,
    out: *mut u8,
    outlen: size_t,
    access: c_int
) -> ssize_t
kcapi_cipher_decrypt() - decrypt data (synchronous one shot)

@handle: [in] cipher handle @in: [in] ciphertext data buffer @inlen: [in] length of in buffer @iv: [in] IV to be used for cipher operation @out: [out] plaintext data buffer @outlen: [in] length of out bufferS @access: [in] kernel access type (KCAPI_ACCESS_HEURISTIC - use internal heuristic for fastest kernel access; KCAPI_ACCESS_VMSPLICE - use vmsplice access; KCAPI_ACCESS_SENDMSG - sendmsg access)

It is perfectly legal to use the same buffer as the plaintext and ciphertext pointers. That would mean that after the encryption operation, the ciphertext is overwritten with the plaintext.

The memory should be aligned at the page boundary using posix_memalign(sysconf(_SC_PAGESIZE)), If it is not aligned at the page boundary, the vmsplice call may not send all data to the kernel.

The IV buffer must be exactly kcapi_cipher_ivsize() bytes in size.

@return number of bytes decrypted upon success; a negative errno-style error code if an error occurred